# Run

## Playbook

## Bundle

## Reports

## Idea:

satori-cli run
satori-cli run playbook.yml
satori-cli run ./
satori-cli run https://github.com/satorici/satori-cli --playbook satori://code/trufflehog.yml
satori-cli run https://github.com/satorici/* --playbook satori://code/trufflehog.yml
satori-cli run https://github.com/satorici/satori-cli/commit/96a654f9efb8962b20a514eccbe827518ca725b2 (e
